import { Component, forwardRef, HostListener, Input, ViewChild, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import 'bootstrap-datepicker';
import { CommonModule } from '@angular/common';

var BASE_OPTION = { autoclose: true, format: 'dd/mm/yyyy' };
var THAI_OPTION = Object.assign({}, BASE_OPTION, { language: 'th-TH' });
var NGQ_DATETIME_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return NgqDatepickerComponent; }),
    multi: true
};
var NgqDatepickerComponent = /** @class */ (function () {
    function NgqDatepickerComponent() {
        this.propagateChange = function (_) { };
        this.onTouched = function () { };
    }
    NgqDatepickerComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        this._datepicker = jQuery(this.input.nativeElement).datepicker(THAI_OPTION);
        this._datepicker.datepicker().on('changeDate', function (e) {
            _this._date = e.date;
            _this.propagateChange(_this._date);
        });
        this._datepicker.datepicker('update', this._date);
        this._datepicker.prop('disabled', this._isDisabled);
    };
    NgqDatepickerComponent.prototype.writeValue = function (obj) {
        this._date = obj;
    };
    NgqDatepickerComponent.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    NgqDatepickerComponent.prototype.registerOnTouched = function (fn) { };
    NgqDatepickerComponent.prototype.setDisabledState = function (isDisabled) {
        this._isDisabled = isDisabled;
    };
    return NgqDatepickerComponent;
}());
NgqDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngq-datepicker',
                template: "<div *ngIf=\"!hideIcon\" class=\"input-group\">\n  <input #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\">\n  <div class=\"input-group-addon\" (click)=\"this._datepicker.datepicker('show')\">\n    <span class=\"glyphicon glyphicon-calendar\"></span>\n  </div>\n</div>\n<input *ngIf=\"hideIcon\" #input type=\"text\" [attr.class]=\"class\" [attr.id]=\"id\" [attr.placeholder]=\"placeholder\">\n",
                styles: [":host{outline:0}"],
                providers: [NGQ_DATETIME_VALUE_ACCESSOR]
            },] },
];
NgqDatepickerComponent.ctorParameters = function () { return []; };
NgqDatepickerComponent.propDecorators = {
    "hideIcon": [{ type: Input },],
    "id": [{ type: Input },],
    "class": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "input": [{ type: ViewChild, args: ['input',] },],
    "onTouched": [{ type: HostListener, args: ['blur',] },],
};
var NgqDatepickerModule = /** @class */ (function () {
    function NgqDatepickerModule() {
    }
    return NgqDatepickerModule;
}());
NgqDatepickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgqDatepickerComponent],
                exports: [NgqDatepickerComponent]
            },] },
];
NgqDatepickerModule.ctorParameters = function () { return []; };

export { NgqDatepickerModule, NgqDatepickerComponent as ɵa };
//# sourceMappingURL=ngq-datepicker.js.map
